/* 
 * File:   main.c
 * Author: Standa
 *
 * Pipojen SPI_RAM(25LC512) k
 * PIC16F73, na PORTC
 *
 * Vstup na LCD(HD44780) 2x16znak
 * pipojen na PORTB
 *
 * Created on 6. bezen 2013, 9:37
 */

#include <htc.h>
#include "configurace.h"
#include "LCD_HD44780_4bit.h"

__CONFIG(FOSC_HS & PWRTE_ON & WDTE_OFF & BOREN_ON);
//****************************************************************************
#define RDSR 0x05
#define READ 0x03
#define WRITE 0x02
#define WREN 0x06
#define WRDI 0x04
#define WRSR 0x01

#define CS  2           //select IO RAM(PORTC.2)

char text2_wr[9] = "25LC512";
char text2_rd[8];
//****************************************************************************
void _delay3s(void)
{
    unsigned char i;
    for(i = 1;i<30;i++)             //30*100ms = 3s
    __delay_ms(100);                //100ms
}

//nastaven SPI
void SPI_Init(void)
{
    TRISC = 0b11010000;
    PORTC = 0b11111111;
    SSPSTAT = 0b11000000;    //SMP = 1,CKE = 1
    SSPCON = 0b00100001;     //SPI on, Fcpu/16 (4MHz/16 = 250kHz)
}

//komunikace na SPI
unsigned char SPI_Transfer(unsigned char data)
{
    unsigned char byte;
    SSPBUF = data;
    while (!(SSPSTATbits.BF));
    byte = SSPBUF;
    return byte;
}

//test stavu RAM
void SPI_Wait(unsigned char select)
{
    unsigned char status = 0;
    do
    {
        PORTC &= ~(1<<select);
        SPI_Transfer(RDSR);
        status = SPI_Transfer(0);
        PORTC |= (1<<select);
    }
    while(status&0x01);
}
//Zpis 1B na adresu v RAM, v rozsahu 1kb..512kb
void Write_EEPROM_1k_512k(unsigned int adrress,unsigned char data,unsigned char select)
{
    SPI_Wait(select);
    PORTC &= ~(1<<select);
    SPI_Transfer(WREN);
    PORTC |= (1<<select);
    PORTC &= ~(1<<select);
    SPI_Transfer(WRITE);
    SPI_Transfer((adrress&0xFF00) >> 8);
    SPI_Transfer(adrress&0x00FF);
    SPI_Transfer(data);
    PORTC |= (1<<select);
}

//ten 1B z adresy v RAM
unsigned char Read_EEPROM_1k_512k(unsigned int adrress,unsigned char select)
{
    unsigned char data = 0;
    SPI_Wait(select);
    PORTC &= ~(1<<select);
    SPI_Transfer(READ);
    SPI_Transfer((adrress&0xFF00) >> 8);
    SPI_Transfer(adrress&0x00FF);
    data = SPI_Transfer(0);
    PORTC |= (1<<select);
    return data;
}

/***********************************************************************
 *
 *      Hlavn program
 *
 ***********************************************************************/
void main(void)
{
    __delay_ms(500);
    unsigned char x;
    SPI_Init();
    Lcd_Init();
//-----------------------------------------------------------------------
    Lcd_Out("Write: ");
    Lcd_Out(text2_wr);
    Lcd_Gotoxy(2,0);
    Lcd_Out("Read : ");

    //Zpis textu do RAM
    x = 0;
    while(text2_wr[x]!= 0)
    {
        Write_EEPROM_1k_512k(x,text2_wr[x],CS);
        x++;
    }

    _delay3s();

    //ten textu z RAM,zobrazen na LCD(kontrola funkce)
    for(x=0;x<7;x++)
    {
        text2_rd[x] = Read_EEPROM_1k_512k(x,CS);
    }

    Lcd_Out(text2_rd);

//---------------------------------------------------------------------------
    while(1)
    {

    }
}
/******************************************************************************/




